BrowserParser class

Constructors

BrowserParser({required String name, String? type, required List<String> regexes})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The browser name, set manually for a browser
final
regexes List<String>
The list of regexes that can possibly parse this browser
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The browser type (e.g., 'browser', 'crawler', 'fetcher', 'cli', 'library')
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited