EngineParser class

Constructors

EngineParser({required String name, required List<String> regexes})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The engine name, set manually for an engine
final
regexes List<String>
The list of regexes that can possibly parse this engine
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited