Browser class

Constructors

Browser({required String name, required String unformattedName, required String version, String? type, required String parsedWithRegex})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The browser name, set manually for a browser
final
parsedWithRegex String
The regex that was used to parse this browser
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The browser type (e.g., 'browser', 'crawler', 'fetcher', 'cli', 'library')
final
unformattedName String
The browser name, parsed directly from the user agent string without modification
final
version String
The browser version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override