unformattedName property
The browser name, parsed directly from the user agent string without modification
Implementation
final String unformattedName;
The browser name, parsed directly from the user agent string without modification
final String unformattedName;