CPU class

Constructors

CPU({required String architecture, required String parsedWithRegex})

Properties

architecture String
The CPU architecture
final
hashCode int
The hash code for this object.
no setteroverride
parsedWithRegex String
The regex that was used to parse this CPU
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override