Engine class

Constructors

Engine({required String name, required String unformattedName, required String version, required String parsedWithRegex})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The engine name, set manually for an engine
final
parsedWithRegex String
The regex that was used to parse this engine
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unformattedName String
The engine name, parsed directly from the user agent string without modification
final
version String
The engine version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override