unformattedName property
The engine name, parsed directly from the user agent string without modification
Implementation
final String unformattedName;
The engine name, parsed directly from the user agent string without modification
final String unformattedName;