unformattedName property
The OS name, parsed directly from the user agent string without modification
Implementation
final String unformattedName;
The OS name, parsed directly from the user agent string without modification
final String unformattedName;