Result class

Constructors

Result({Browser? browser, Engine? engine, OS? os, Device? device, CPU? cpu})

Properties

browser Browser?
getter/setter pair
cpu CPU?
getter/setter pair
device Device?
getter/setter pair
engine Engine?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
os OS?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited