UserAgentParser class

Constructors

UserAgentParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseBrowser(String userAgent) Browser?
Parse a Browser from the userAgent string.
parseCPU(String userAgent) CPU?
Parse a CPU from the userAgent string.
parseDevice(String userAgent) Device?
Parse a Device from the userAgent string.
parseEngine(String userAgent) Engine?
Parse an Engine from the userAgent string.
parseOS(String userAgent) OS?
Parse an OS from the userAgent string.
parseResult(String userAgent) Result
Parse a Result from the userAgent string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited