Device class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
model
→ String
-
The device model
final
-
parsedWithRegex
→ String
-
The regex that was used to parse this device
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ String
-
The device type (mobile, tablet, desktop, etc.)
final
-
vendor
→ String
-
The device vendor (Apple, Samsung, etc.)
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited