OS class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
The OS name, set manually for an OS
final
- parsedWithRegex → String
-
The regex that was used to parse this OS
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unformattedName → String
-
The OS name, parsed directly from the user agent string without modification
final
- version → String
-
The OS version
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override