UserAgentParser class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseBrowser(
String userAgent) → Browser? -
Parse a Browser from the
userAgentstring. -
parseCPU(
String userAgent) → CPU? -
Parse a CPU from the
userAgentstring. -
parseDevice(
String userAgent) → Device? -
Parse a Device from the
userAgentstring. -
parseEngine(
String userAgent) → Engine? -
Parse an Engine from the
userAgentstring. -
parseOS(
String userAgent) → OS? -
Parse an OS from the
userAgentstring. -
parseResult(
String userAgent) → Result -
Parse a Result from the
userAgentstring. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited